==> toutdoux-1.2.4.tar.gz: ToutDoux-1.2.4/lib/td_db_mod.h <==
/*****************************************************************************/
/* td_db_mod.h : Objet Gtk+
 * td_db_mod.h : Gtk+ object
 *
 *
 * ToutDoux : Chtit gestionnaire de projet - A littl' project manager
 * Copyright (c) 2000 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@yahoo.com>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <parser.h>
#include <tree.h>


/*****************************************************************************/
/* Macros */
/*****************************************************************************/
#define TD_TYPE_DB_MOD (td_db_mod_get_type ())
#define TD_DB_MOD(obj) (GTK_CHECK_CAST ((obj), TD_TYPE_DB_MOD, TdDbMod))
#define TD_DB_MOD_CLASS(klass) (GTK_CHECK_CLASS_CASTS ((klass), TD_TYPE_DB_MOD, TdDbModClass))
#define TD_IS_DB_MOD(obj) (GTK_CHECK_TYPE ((obj), TD_TYPE_DB_MOD))
#define TD_IS_DB_MOD_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TD_TYPE_DB_MOD))

/*****************************************************************************/
/* Structure */
/*****************************************************************************/
typedef struct _TdDbMod TdDbMod;
typedef struct _TdDbModClass TdDbModClass;

struct _TdDbMod
{
  GtkObject object;
  gchar *name;
  gchar *table;
  GList *field;
};

struct _TdDbModClass
{
  GtkObjectClass parent_class;
  void (*add_field) (TdDbMod *db_mod, GtkObject *field);
};

/*****************************************************************************/
/* Arguments */
/*****************************************************************************/
void td_db_mod_set_name (TdDbMod *db_mod, gchar *name);
void td_db_mod_set_table (TdDbMod *db_mod, gchar *table);
static void td_db_mod_set_arg (GtkObject *object, GtkArg *arg, guint arg_id);
static void td_db_mod_get_arg (GtkObject *object, GtkArg *arg, guint arg_id);

/*****************************************************************************/
/* Initialisation */
/*****************************************************************************/
static void td_db_mod_init (TdDbMod *db_mod);
static void td_db_mod_class_init (TdDbModClass *klass);
GtkType td_db_mod_get_type (void);
GtkObject *td_db_mod_new (void);

/*****************************************************************************/
/* Affectations */
/*****************************************************************************/
void td_db_mod_add_field (TdDbMod *db_mod, GtkObject *field);

/*****************************************************************************/
/* Commandes */
/*****************************************************************************/

/*****************************************************************************/
/* Fichier */
/*****************************************************************************/
GtkObject *td_db_mod_load_hopla (xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur);

==> toutdoux-1.2.7.tar.gz: ToutDoux-1.2.7/lib/td_db_mod.h <==
/*****************************************************************************/
/* td_db_mod.h : Objet Gtk+
 * td_db_mod.h : Gtk+ object
 *
 *
 * ToutDoux : Chtit gestionnaire de projet - A littl' project manager
 * Copyright (c) 2000-2001 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@toutdoux.org>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <parser.h>
#include <tree.h>
/*  #include <libxml/parser.h> */
/*  #include <libxml/tree.h> */

/*****************************************************************************/
/*** Macros */
/*****************************************************************************/
#define TD_TYPE_DB_MOD (td_db_mod_get_type())
#define TD_DB_MOD(obj) (GTK_CHECK_CAST ((obj), TD_TYPE_DB_MOD, TdDbMod))
#define TD_DB_MOD_CLASS(klass) (GTK_CHECK_CLASS_CASTS ((klass), TD_TYPE_DB_MOD, TdDbModClass))
#define TD_IS_DB_MOD(obj) (GTK_CHECK_TYPE ((obj), TD_TYPE_DB_MOD))
#define TD_IS_DB_MOD_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TD_TYPE_DB_MOD))

/*****************************************************************************/
/*** Structure */
/*****************************************************************************/
typedef struct _TdDbMod TdDbMod;
typedef struct _TdDbModClass TdDbModClass;

struct _TdDbMod
{
  /*< public >*/
  GtkObject object;
  gchar *name; /*** Nom officiel - Official name */
  gchar *name_param; /*** Nom - Name */
  gchar *group; /*** Groupe - Group */
  gchar *comment; /*** Commantaire - Comment */
  gchar *icon; /*** Icne - Icon */
  GList *table; /*** Paramtrage des tables - Tables parameters */
  GList *interface_field; /*** Paramtrage de l'interface - Interface parameters */
  GList *bench_field; /*** Paramtrage de l'tabli - Bench parameters */
  GList *etabliste_field; /*** Paramtrage de l'tabliste - Bench of lists parameters */
  GtkObject *menu; /*** Paramtrage du menu - Menu parameters */
};

struct _TdDbModClass
{
  GtkObjectClass parent_class;
  void (*add_table) (TdDbMod *db_mod, GtkObject *table);
  void (*add_interface_field) (TdDbMod *db_mod, GtkObject *interface_field);
  void (*add_bench_field) (TdDbMod *db_mod, GtkObject *bench_field);
  void (*add_etabliste_field) (TdDbMod *db_mod, GtkObject *etabliste_field);
  void (*set_menu) (TdDbMod *db_mod, GtkObject *menu);
};

/*****************************************************************************/
/*** Arguments */
/*****************************************************************************/
static void td_db_mod_set_name (TdDbMod *db_mod, gchar *name);
static void td_db_mod_set_name_param (TdDbMod *db_mod, gchar *name_param);
static void td_db_mod_set_group (TdDbMod *db_mod, gchar *group);
static void td_db_mod_set_comment (TdDbMod *db_mod, gchar *comment);
static void td_db_mod_set_icon (TdDbMod *db_mod, gchar *icon);
static void td_db_mod_set_arg (GtkObject *object, GtkArg *arg, guint arg_id);
static void td_db_mod_get_arg (GtkObject *object, GtkArg *arg, guint arg_id);

/*****************************************************************************/
/*** Initialisation */
/*****************************************************************************/
static void td_db_mod_init (TdDbMod *db_mod);
static void td_db_mod_class_init (TdDbModClass *klass);
GtkType td_db_mod_get_type (void);
GtkObject *td_db_mod_new (void);

/*****************************************************************************/
/*** Affectations - Allocations */
/*****************************************************************************/
void td_db_mod_add_table (TdDbMod *db_mod, GtkObject *table);
void td_db_mod_add_interface_field (TdDbMod *db_mod, GtkObject *interface_field);
void td_db_mod_add_bench_field (TdDbMod *db_mod, GtkObject *bench_field);
void td_db_mod_add_etabliste_field (TdDbMod *db_mod, GtkObject *etabliste_field);
void td_db_mod_set_menu (TdDbMod *db_mod, GtkObject *menu);

/*****************************************************************************/
/*** Fichier - File */
/*****************************************************************************/
GtkObject *td_db_mod_load (XmlDoc *doc, XmlNs *ns, XmlNode *cur_root);
